@@ -282,6 +282,56 @@ weather_summary_get_logo(plugin_data *data)
 }
 
 
+static gboolean
+text_view_key_pressed_cb (GtkWidget   *widget,
+                          GdkEventKey *event,
+                          gpointer     user_data)
+{
+    GtkScrolledWindow *scrolled = GTK_SCROLLED_WINDOW (user_data);
+    GtkAdjustment *adjustment = gtk_scrolled_window_get_vadjustment (scrolled);
+    gdouble current = gtk_adjustment_get_value (adjustment);
+    gdouble min = gtk_adjustment_get_lower (adjustment);
+    gdouble max = gtk_adjustment_get_upper (adjustment);
+    gdouble step_size = 0;
+
+    switch (event->keyval) {
+        case GDK_KEY_Up:
+        case GDK_KEY_uparrow:
+            step_size = -1 * gtk_adjustment_get_step_increment (adjustment);
+            break;
+        case GDK_KEY_Down:
+        case GDK_KEY_downarrow:
+            step_size = gtk_adjustment_get_step_increment (adjustment);
+            break;
+        case GDK_KEY_Page_Up:
+            step_size = -1 * gtk_adjustment_get_page_size (adjustment);
+            break;
+        case GDK_KEY_Page_Down:
+        case GDK_KEY_space:
+            step_size = gtk_adjustment_get_page_size (adjustment);
+            break;
+        case GDK_KEY_Home:
+            step_size = -1 * current;
+            break;
+        case GDK_KEY_End:
+            step_size = max;
+            break;
+    }
+
+    if (step_size != 0) {
+        current = current + step_size;
+        if (current < min) current = min;
+        if (current > max) current = max;
+
+        gtk_adjustment_set_value (adjustment, current);
+
+        return TRUE;
+    }
+
+    return FALSE;
+}
+
+
 static GtkWidget *
 create_summary_tab(plugin_data *data)
 {
@@ -311,9 +361,12 @@ create_summary_tab(plugin_data *data)
     gtk_text_view_set_top_margin (GTK_TEXT_VIEW(view), 12);
     gtk_text_view_set_right_margin (GTK_TEXT_VIEW(view), 12);
     gtk_text_view_set_bottom_margin (GTK_TEXT_VIEW(view), 12);
+
     frame = gtk_frame_new(NULL);
     scrolled = gtk_scrolled_window_new(NULL, NULL);
 
+    g_signal_connect(GTK_WIDGET(view), "key-press-event", G_CALLBACK(text_view_key_pressed_cb), scrolled);
+
     overlay = gtk_overlay_new ();
     gtk_container_add (GTK_CONTAINER (overlay), view);
 
@@ -355,12 +408,12 @@ create_summary_tab(plugin_data *data)
     /* Check for deprecated API and issue a warning if necessary */
     if (data->weather_update->http_status_code == 203)
         APPEND_BTEXT
-            (_("\tMet.no LocationforecastLTS API states that this version\n"
+            (_("\tMet.no Locationforecast API states that this version\n"
                "\tof the webservice is deprecated, and the plugin needs to be\n"
                "\tadapted to use a newer version, or it will stop working within\n"
                "\ta few months.\n"
-               "\tPlease file a bug on https://bugzilla.xfce.org if no one\n"
-               "\telse has done so yet.\n\n"));
+               "\tPlease file a bug on https://gitlab.xfce.org/panel-plugins/xfce4-weather-plugin/\n"
+               "\tif no one else has done so yet.\n\n"));
 
     last_download = format_date(data->astro_update->last, NULL, TRUE);
     next_download = format_date(data->astro_update->next, NULL, TRUE);
@@ -381,8 +434,8 @@ create_summary_tab(plugin_data *data)
             (_("\n\tMet.no sunrise API states that this version of the webservice\n"
                "\tis deprecated, and the plugin needs to be adapted to use\n"
                "\ta newer version, or it will stop working within a few months.\n"
-               "\tPlease file a bug on https://bugzilla.xfce.org if no one\n"
-               "\telse has done so yet.\n"));
+               "\tPlease file a bug on https://gitlab.xfce.org/panel-plugins/xfce4-weather-plugin/\n"
+               "\tif no one else has done so yet.\n\n"));
 
     /* calculation times */
     APPEND_BTEXT(_("\nTimes Used for Calculations\n"));
@@ -417,12 +470,12 @@ create_summary_tab(plugin_data *data)
             value = g_strdup(_("\tSunset:\t\tThe sun never sets today.\n"));
             APPEND_TEXT_ITEM_REAL(value);
         } else {
-            sunrise = format_date(data->current_astro->sunrise, NULL, FALSE);
+            sunrise = format_date(data->current_astro->sunrise, NULL, TRUE);
             value = g_strdup_printf(_("\tSunrise:\t\t%s\n"), sunrise);
             g_free(sunrise);
             APPEND_TEXT_ITEM_REAL(value);
 
-            sunset = format_date(data->current_astro->sunset, NULL, FALSE);
+            sunset = format_date(data->current_astro->sunset, NULL, TRUE);
             value = g_strdup_printf(_("\tSunset:\t\t%s\n\n"), sunset);
             g_free(sunset);
             APPEND_TEXT_ITEM_REAL(value);
@@ -445,12 +498,12 @@ create_summary_tab(plugin_data *data)
                 g_strdup(_("\tMoonset:\tThe moon never sets today.\n"));
             APPEND_TEXT_ITEM_REAL(value);
         } else {
-            moonrise = format_date(data->current_astro->moonrise, NULL, FALSE);
+            moonrise = format_date(data->current_astro->moonrise, NULL, TRUE);
             value = g_strdup_printf(_("\tMoonrise:\t%s\n"), moonrise);
             g_free(moonrise);
             APPEND_TEXT_ITEM_REAL(value);
 
-            moonset = format_date(data->current_astro->moonset, NULL, FALSE);
+            moonset = format_date(data->current_astro->moonset, NULL, TRUE);
             value = g_strdup_printf(_("\tMoonset:\t%s\n"), moonset);
             g_free(moonset);
             APPEND_TEXT_ITEM_REAL(value);
@@ -699,13 +752,13 @@ forecast_day_header_tooltip_text(xml_astro *astro)
                                     "Sunset: The sun never sets this day."
                                     "</small></tt>\n"));
         else {
-            sunrise = format_date(astro->sunrise, NULL, FALSE);
+            sunrise = format_date(astro->sunrise, NULL, TRUE);
             g_string_append_printf(text, _("<tt><small>"
                                            "Sunrise: %s"
                                            "</small></tt>\n"), sunrise);
             g_free(sunrise);
 
-            sunset = format_date(astro->sunset, NULL, FALSE);
+            sunset = format_date(astro->sunset, NULL, TRUE);
             g_string_append_printf(text, _("<tt><small>"
                                            "Sunset:  %s"
                                            "</small></tt>\n\n"), sunset);
@@ -732,13 +785,13 @@ forecast_day_header_tooltip_text(xml_astro *astro)
                               "Moonset: The moon never sets this day."
                               "</small></tt>\n"));
         else {
-            moonrise = format_date(astro->moonrise, NULL, FALSE);
+            moonrise = format_date(astro->moonrise, NULL, TRUE);
             g_string_append_printf(text, _("<tt><small>"
                                            "Moonrise: %s"
                                            "</small></tt>\n"), moonrise);
             g_free(moonrise);
 
-            moonset = format_date(astro->moonset, NULL, FALSE);
+            moonset = format_date(astro->moonset, NULL, TRUE);
             g_string_append_printf(text, _("<tt><small>"
                                            "Moonset:  %s"
                                            "</small></tt>"), moonset);
@@ -894,13 +947,17 @@ make_forecast(plugin_data *data)
     GtkCssProvider *provider = gtk_css_provider_new ();
     gchar *css_string;
 
-    css_string = g_strdup (".forecast-cell.lightbg { background-color: rgba(0, 0, 0, 0.2); }"
-                           ".forecast-cell.darkbg { background-color: rgba(0, 0, 0, 0.4); }");
+    GtkStyleContext *ctx;
+
+    css_string = g_strdup (".forecast-cell.lightbg { background-color: rgba(0, 0, 0, 0.05); }"
+                           ".forecast-cell.darkbg { background-color: rgba(0, 0, 0, 0.6); }");
 
     gtk_css_provider_load_from_data (provider, css_string, -1, NULL);
     gtk_style_context_add_provider_for_screen (screen, GTK_STYLE_PROVIDER (provider), GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
 
     grid = gtk_grid_new ();
+    ctx = gtk_widget_get_style_context (GTK_WIDGET (grid));
+    gtk_style_context_add_class (ctx, "background");
 
     gtk_grid_set_row_spacing(GTK_GRID (grid), 0);
     gtk_grid_set_column_spacing(GTK_GRID (grid), 0);
@@ -1067,7 +1124,6 @@ gboolean
 update_summary_subtitle(plugin_data *data)
 {
     time_t now_t;
-    GTimeVal now;
     gchar *title, *date;
     guint update_interval;
     gint64 now_ms;
@@ -1083,15 +1139,14 @@ update_summary_subtitle(plugin_data *data)
 
     time(&now_t);
     date = format_date(now_t, "%Y-%m-%d %H:%M:%S (%Z)", TRUE);
-    title = g_strdup_printf("%s\n%s", data->location_name, date);
+    title = g_strdup_printf("%s   %s", data->location_name, date);
     g_free(date);
     xfce_titled_dialog_set_subtitle(XFCE_TITLED_DIALOG(data->summary_window),
                                     title);
     g_free(title);
 
     /* compute and schedule the next update */
-    g_get_current_time(&now);
-    now_ms = ((gint64) now.tv_sec * 1000) + ((gint64) now.tv_usec / 1000);
+    now_ms = g_get_real_time () / 1000;
 #ifdef HAVE_UPOWER_GLIB
     if (data->upower_on_battery)
         update_interval = 60000 - (now_ms % 60000) + 10;
